#
# spec file for package steam
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define dependency() \
%ifarch %{ix86} \
Requires: %{1} \
%else \
Requires: %{1}-32bit \
%endif \
%{nil}
%define booldependency() \
%ifarch x86_64 \
Requires: (%{1}-32bit if %{1}) \
%endif \
%{nil}
%define nvidia_dependency() \
%ifarch x86_64 \
%booldependency %{1}G04 \
%booldependency %{1}G05 \
%booldependency %{1}G06 \
%endif \
%{nil}
Name:           steam
Version:        1.0.0.82
Release:        1.1
Summary:        Installer for Valve's digital software distribution service
# "Limited Installation License"
License:        SUSE-Freeware
Group:          Amusements/Games/Other
URL:            https://www.steampowered.com/
Source0:        https://repo.steampowered.com/steam/archive/stable/%{name}_%{version}.tar.gz
# PATCH-FIX-OPENSUSE steam-path-fix.patch bnc#1025841
Patch0:         steam-path-fix.patch
Patch1:         gpu-offload.patch
BuildRequires:  fdupes
BuildRequires:  firewall-macros
BuildRequires:  hicolor-icon-theme
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
# from steamdeps.txt which uses Debian package syntax
Requires:       curl
Requires:       libz.so.1
# for Steam Hardware Survey
Requires:       lsb-release
Requires:       openal-soft
# Proton Requirements
Requires:       glibc-locale-base
Requires:       python3
Requires:       tar
Requires:       xz
Requires:       zenity
Recommends:     bubblewrap
ExclusiveArch:  %{ix86} x86_64
%nvidia_dependency x11-video-nvidia
%nvidia_dependency nvidia-compute
%nvidia_dependency nvidia-gl
%booldependency  Mesa-libGL1
%booldependency  libvulkan_intel
%booldependency  libvulkan_radeon
%dependency  libvulkan1
%dependency  dbus-1-glib
%dependency  gtk2-engine-oxygen
%dependency  libSDL2-2_0-0
%dependency  libX11-6
%dependency  libXdmcp6
%dependency  libXext6
%dependency  libXfixes3
%dependency  libXi6
%dependency  libXrandr2
%dependency  libXrender1
%dependency  libatk-1_0-0
%dependency  libcairo2
%dependency  libcurl4
%dependency  libdbus-1-3
%dependency  libfreetype6
%dependency  libgcrypt20
%dependency  libgdk_pixbuf-2_0-0
%dependency  libglib-2_0-0
%dependency  libgmodule-2_0-0
%dependency  libgobject-2_0-0
%dependency  libgtk-2_0-0
%dependency  libogg0
%dependency  libpango-1_0-0
%dependency  libpixman-1-0
%dependency  libpng12-0
%dependency  libpulse0
%dependency  libtheora0
%dependency  libvorbis0
%dependency  mozilla-nspr
%dependency  mozilla-nss
%dependency  libcups2
%dependency  fontconfig
%dependency  glibc
%dependency  libgcc_s1
%dependency  libopenal1
%dependency  libstdc++6
%dependency  libcrypt1
%dependency  libudev1
%dependency  libxcb-dri2-0
%dependency  libxcb-glx0
%dependency  libxcb-res0
%dependency  libdrm2
%dependency  libXtst6
%dependency  libva2
%dependency  libva-drm2
%dependency  libva-x11-2
%dependency  libva-glx2
%dependency  libvdpau1
%dependency  libICE6
%dependency  libSM6
%dependency  libusb-1_0-0
%dependency  libpipewire-0_3-0
%dependency  libxkbcommon-x11-0
%booldependency  libgbm1
%if 0%{?suse_version} >= 1600 || 0%{?sle_version} >= 150600
%dependency  libavif16
%endif
%if 0%{?suse_version} >= 1600 || 0%{?sle_version} >= 150500
%booldependency  libnm0
%endif

%description
Steam is a software distribution service with an online store, automated
installation, automatic updates, achievements, SteamCloud synchronized
savegame and screenshot functionality, and many social features.

This package will fetch and install the Steam bootstrap. Start Steam to
complete the installation of the client for the current user.

%prep
%autosetup -N -n steam-launcher
%if 0%{?suse_version} < 1550
%patch -P 0 -p1
%endif
%if 0%{?suse_version} < 1550 && 0%{?sle_version} < 150400
%patch -P 1 -p1
%endif


%build
true

%install
make DESTDIR=%{buildroot} install-bin install-docs install-icons install-bootstrap install-desktop install-appdata


find %{buildroot} -type f -exec sed -i 's|#!%{_bindir}/env |#!%{_bindir}/|g' {} \;
# Remove steamdeps as it is apt specific
rm -f %{buildroot}%{_bindir}/%{name}deps

%fdupes -s %{buildroot}

%files
%{_bindir}/*
%{_prefix}/lib/%{name}
%{_datadir}/pixmaps/%{name}_tray_mono.png
%{_datadir}/pixmaps/%{name}.png
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/*/apps/%{name}.png
%dir %{_datadir}/doc/%{name}
%doc %{_datadir}/doc/%{name}/steam_subscriber_agreement.txt
%doc %{_datadir}/doc/%{name}/README
%doc debian/changelog
%{_mandir}/man6/%{name}.6%{?ext_man}
%{_datadir}/metainfo/*

%changelog
* Tue Feb  4 2025 Callum Farmer <gmbr3@opensuse.org>
- Update to version 1.0.0.82:
  - Client timestamp 1726604483 (2024-09-17)
  - Steam Runtime (scout) version 0.20240806.97925
* Mon Sep 30 2024 Callum Farmer <gmbr3@opensuse.org>
- Update to version 1.0.0.81:
  - Client timestamp 1721173382 (2024-07-16)
  - Steam Runtime (scout) version 0.20240610.91380
- Update RPM constructs (autosetup/patch)
* Wed Jun 12 2024 Callum Farmer <gmbr3@opensuse.org>
- Library changes:
  * Use SDL2 instead of SDL
  * Add libxcb-res0
  * Add libavif16 (for TW and Leap 15.6+)
* Tue Jun  4 2024 Dirk Müller <dmueller@suse.com>
- depend on glibc-locale-base as glibc-locale-base-32bit has
  been dropped (now part of glibc-32bit)
* Wed Feb 14 2024 Carsten Ziepke <kieltux@gmail.com>
- Update to version 1.0.0.79:
  * bin_steam.sh:
  - When running in a Gamescope session, only write messages to
    the log. Don't pop up a zenity or xterm window, which would
    not be shown by the Gamescope session.
  - If ~/.steam/steam is a dangling symlink, don't prompt users
    to browse for the correct location or reinstall. Instead,
    just reinstall non-interactively.
  * Build using updated Steam client:
  - Client timestamp 1705108172 (2023-01-13)
  - Steam Runtime (scout) version 0.20231127.68515
- Run spec-cleaner
* Wed Jan 31 2024 Richard Brown <rbrown@suse.com>
- Remove steam-devices subpackage, to be replaced by steam-devices
  real package.
- This is to allow steam-devices (which is MIT licensed)to be
  included in the Tumbleweed OSS repo.
* Sat Aug 26 2023 Antonio Teixeira <antonio.teixeira@suse.com>
- Remove libopenssl1_0_0-steam dependencies.
  * Originally added as a workaround to an upstream bug which has
    since been fixed (steam-for-linux#4619)
- Remove steamtricks dependency.
  * Project is unmaintained. The OpenSSL fix is both broken and
    needed anymore.
  * Drop steam-invoke_steamtricks.patch
- Remove steamdeps from the package as it is apt specific. This was
  previously handled by steamtricks.
* Thu May 11 2023 Callum Farmer <gmbr3@opensuse.org>
- Update to version 1.0.0.78:
  * Build using updated Steam client:
  - Client timestamp 1682708537 (2023-04-28)
  - Steam Runtime (scout) version 0.20230118.0
  * Update steam-devices subproject up to 2023-04-12:
  - steam-input: Add Razer Raiju Ultimate
  - steam-input: Add Sony DualShock 3 (Playstation 3) controller
  - steamvr: Provide access to Valve Index (28de:2102) serial
    port
* Thu Mar 16 2023 Callum Farmer <gmbr3@opensuse.org>
- Update to version 1.0.0.76:
  * Build using updated Steam client:
  - Client timestamp 1676336721 (2023-02-14)
  - Steam Runtime version 0.20221019.0
* Thu Dec 22 2022 Callum Farmer <gmbr3@opensuse.org>
- Change libz dependency to a soname dependency to allow zlib-ng
* Mon Jul 18 2022 Dario Faggioli <dfaggioli@suse.com>
- Make Steam only a soft dependency of steam-devices
  * the steam-devices package is useful for having controllers
    working also in cases Steam and SteamLink are consumed as
    flatpaks (in which case, one might not want Steam installed
    from RPMs as well!)
* Fri Jul 15 2022 Callum Farmer <gmbr3@opensuse.org>
- Update to version 1.0.0.75:
  * Build using updated Steam client:
  - Client timestamp 1654574690 (2022-06-07)
  - Steam Runtime version 0.20220315.0
* Thu May 26 2022 Callum Farmer <gmbr3@opensuse.org>
- Make sure 32bit NVIDIA drivers are installed where necessary
* Wed Apr  6 2022 Callum Farmer <gmbr3@opensuse.org>
- Require tar (boo#1198118)
* Sun Jan 30 2022 Callum Farmer <gmbr3@opensuse.org>
- steam-path-fix.patch is no longer required on TW
* Fri Jan  7 2022 Callum Farmer <gmbr3@opensuse.org>
- Allow PrefersNonDefaultGPU on 15.4
* Fri Dec  3 2021 Callum Farmer <gmbr3@opensuse.org>
- Update to version 1.0.0.74:
  * Build using updated Steam client:
  - Client timestamp 1637624439 (2021-11-02)
  - Steam Runtime version 0.20211102.0
* Thu Nov 11 2021 Callum Farmer <gmbr3@opensuse.org>
- Update to version 1.0.0.73:
  * Build using updated Steam client:
  - Client timestamp 1634158817 (2021-10-13)
  - Steam Runtime version 0.20210906.1
* Sun Nov  7 2021 Callum Farmer <gmbr3@opensuse.org>
- Add libgbm1 to all versions
* Fri Nov  5 2021 Callum Farmer <gmbr3@opensuse.org>
- Add libgbm1 to bool dependencies (boo#1192277)
* Thu Sep  9 2021 Callum Farmer <gmbr3@opensuse.org>
- Update to version 1.0.0.72:
  * Update steam-devices subproject up to 2021-08-25
  - Brooks Universal Fighting Board
  - PowerA Wired Controller for Nintendo Switch
  - Razer Panthera EVO Arcade Stick
  - Razer Raiju PS4 Tournament Edition over Bluetooth
  - Thrustmaster eSwap Pro
* Sun Aug  8 2021 Callum Farmer <gmbr3@opensuse.org>
- Fix dependencies for Leap 15.2 & 15.3
* Tue Aug  3 2021 Callum Farmer <gmbr3@opensuse.org>
- Add libnm0 to bool dependencies, not needed if not using NM
* Mon Jul 26 2021 Callum Farmer <gmbr3@opensuse.org>
- Update requires based on Steam warnings
* Sun Jul 25 2021 Callum Farmer <gmbr3@opensuse.org>
- Update to version 1.0.0.71
  * Build using updated Steam client:
  - Client timestamp 1626824053 (2021-07-20)
  - Steam Runtime version 0.20210630.0
  * Update steam-devices subproject up to 2021-06-10
  - PDP Wired Fight Pad Pro for Nintendo Switch
  - Razer Raiju 2 Tournament Edition (USB)
  - Horipad mini 4
- Remove steam-no-icon-on-desktop.patch: unneeded
- Remove steam-makefile.patch: unneeded
* Sat Jul  3 2021 Matthias Mailänder <mailaender@opensuse.org>
- Soft dependency on steamtricks (boo#1180469)
* Wed Jun 30 2021 Callum Farmer <gmbr3@opensuse.org>
- Require glibc-locale-base for some games
- Allow Mesa to be removed
- Require lsb-release so we get found on Hardware Survey
* Thu Apr 15 2021 Callum Farmer <gmbr3@opensuse.org>
- Update to version 1.0.0.70
  * Request running on a discrete or otherwise "big" GPU
  * Build using updated Steam client:
  - Client timestamp 1616532526 (2021-03-23)
  - Steam Runtime version 0.20210126.2
* Sat Mar 20 2021 Callum Farmer <gmbr3@opensuse.org>
- Leap 15.3 doesn't need firewall rule
* Fri Mar  5 2021 Callum Farmer <gmbr3@opensuse.org>
- Update to version 1.0.0.69
  * Register to handle steamlink:// URLs.
  * Update steam-devices subproject up to 2020-12-08
* Mon Feb  8 2021 Callum Farmer <gmbr3@opensuse.org>
- Make x86 only
* Sat Dec  5 2020 Callum Farmer <gmbr3@opensuse.org>
- Update to version 1.0.0.68
  * Minor changes
- Deal with gpu-offload.patch better
* Sun Nov 22 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Update to version 1.0.0.67
  * Update steam-devices subproject up to 2020-11-20
  - Add udev rules for DualSense (Playstation 5) controller
  * Build using updated Steam client:
  - Client timestamp 1603992987 (2020-10-29)
  - Steam Runtime version 0.20201005.0
* Fri Sep 25 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Add udev rules to fix devices detected as joysticks incorrectly
- Only install firewalld rule when required
* Wed Sep  2 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Add new Mesa packages to Requires for Tumbleweed
- Keep old Requires for Leap maintenance
- Add gpu-offload.patch: default to discrete gpu - from pop-os!
- Use both Steam OpenSSL versions
* Sat Aug 15 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Update AppStream files
- Add patches from RPMFusion:
  * steam-makefile.patch: remove pointless symlinks
    and apt-source install
  * steam-no-icon-on-desktop.patch: remove attempt
    to copy .desktop to user desktop
* Thu Aug  6 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Simplification of OpenSSL requires
* Thu Aug  6 2020 Callum Farmer <callumjfarmer13@gmail.com>
- vulkan doesn't exist since Leap 15.2
- libvulkan1-32bit doesn't exist on non-64bit systems
- vulkan libraries should be required
* Thu Jul 30 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Update to version 1.0.0.66
  * Bootstrap using updated Steam client:
  - Client timestamp 1595977781 (2020-07-28)
  - Steam Runtime version 0.20200604.0
  * Update steam-devices subproject up to 2020-07-28
  - Replace escaped double quotes in udev rules with single quotes, for
    compatibility with udev < 235 and eudev.
- Add Recommends: bubblewrap, required by the experimental container
  runtime system
- Switch to FirewallD
* Wed Jun 17 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Update to version 1.0.0.63
  * Update steam-devices subproject up to 2020-06-05
  - Add HORIPAD for Nintendo Switch (thanks, @BrokenGale)
    (Fixes: steam-for-linux#6944, steam-devices#7)
  - Add ASTRO C40 controller (thanks, @exhumer2)
    (Fixes: steam-devices#5)
  - Add PowerA Nintendo Switch Controller (thanks, @blazingkin)
    (Fixes: steam-devices#6)
  - Add a workaround for PowerA Wireless Controller
    (thanks, Andrey Smirnov) (Fixes: steam-devices#9; T21767)
  * debian/steam-launcher.postinst: Notify udevd to reload its rules.
    This means the steam-devices rules should take effect immediately,
    instead of being deferred until after the next reboot. (T19535)
  * bin_steam.sh: Don't overwrite steam.desktop if it's a symlink.
    In a pre-configured distro like SteamOS, ~/Desktop/steam.desktop
    might already be a symlink to /usr/share/applications/steam.desktop,
    in which case overwriting it is pointless. (T21633)
- steam-devices supplements steam
- Update to version 1.0.0.64
  * steam.list: Download updates via https (T21740)
    In older versions of apt (lower than 1.6) we need to install
    apt-transport-https to use https repositories, so do that.
  * steam.list: Switch the suite from precise to stable
    (Fixes: steam-for-linux#4436)
  * steam.list: Add commented-out apt sources for the beta launcher
* Fri Jun  5 2020 Matthias Mailänder <mailaender@opensuse.org>
- Added recommend lsb-release to provide OS info and to support
  hw survey boo#1157832
* Sat May 23 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Update patches for new package structure
- Merge steam-controller and steam-vr into steam-devices like other distros.
- Update to version 1.0.0.62
  * Adapt for newer Steam Runtime builds
* Mon Dec 30 2019 Dominique Leuenberger <dimstar@opensuse.org>
- Drop libnm-glib4 and libnm-util2 dependencies: steam appears to
  run just fine without those libs nowadays (boo#1157903).
* Thu Oct  3 2019 Yunhe Guo <i@guoyunhe.me>
- Remove unnecessary desktop file modification
  * Original is good: Categories=Network;FileTransfer;Game;
  * Modified, Categories=Game;Amusement;, will list steam in Games >
    Toys category in KDE, which doesn't fit a game store.
* Wed Jun 12 2019 Jon Brightwell <jon@moozaad.co.uk>
- update to version 1.0.0.61
  * Update udev rules
- includes version 1.0.0.60
  * Updates to the bootstraping logic and bootstraping runtime
- Added steam-path-fix.patch to correct lspci not found
* Mon Mar 25 2019 Stasiek Michalski <hellcp@mailbox.org>
- Add recommended 32bit vulkan library
* Thu Dec 20 2018 mailaender@opensuse.org
- update to version 1.0.0.59
  * Update udev rules.
  * Add --run option to the steam command, will exec a command
    through run.sh in the steam runtime environment.
* Sat Sep 29 2018 Avindra Goolcharan <avindra@opensuse.org>
- update to version 1.0.0.56
  * Rename udev rules files to 60-* to fix permissions to /dev/uinput
    for the currently logged in user.
- includes version 1.0.0.55
  * Update locstrings for .desktop file
  * Update udev rules for VR and controllers
- drop allow-non-root-controller-access.patch (fixed upstream)
- partial cleanup with spec-cleaner
* Sun Aug 26 2018 jon@moozaad.co.uk
- Added proton requirements (python3) and recommended vulkan
* Tue Nov 14 2017 christophe@krop.fr
- Require libcups2-32bit if the package is available. (boo#1067133)
* Sat Aug  5 2017 mailaender@opensuse.org
- Require "games" group and user (boo#1043738)
* Sat Mar 11 2017 robert.munteanu@gmail.com
- Add firewall file to allow easier access to in-home streaming
* Wed Dec 21 2016 jimmy@boombatower.com
- Replace steamruntime-fix with steamtricks.
  invoke-libstdc-removal-before-starting-steam.patch
  steam-invoke_steamtricks.patch
* Tue Dec 13 2016 develop7@develop7.info
- update to version 1.0.0.54
- refreshed allow-non-root-controller-access.patch
* Sat Nov 19 2016 mailaender@opensuse.org
- update to version 1.0.0.53
  * Update udev rules for HTC Vive and order them so they run after
  50-udev-default.rules but before 73-seat-late.rules
- Add appdata.xml for https://software.opensuse.org/appstore
* Sat Oct  1 2016 jimmy@boombatower.com
- Surround all home directory usages with quotes.
* Wed Sep 28 2016 jimmy@boombatower.com
- Search and remove libstdc from steam library directories as well
  to ensure apps shipping their own incompatible versions work.
* Mon Sep 26 2016 jimmy@boombatower.com
- correct replacement of 64bit openssl libraries in steamruntime.
* Mon Sep 12 2016 meissner@suse.com
- require our own builds of the openssl libraries
  and replace them on runtime. bsc#988273
* Mon Aug 15 2016 rpm@fthiessen.de
- Added allow-non-root-controller-access.patch for fixing
  boo#986901
- Droped special handling of openSUSE <= 12.3 as it is not
  maintained anymore.
* Sun Jul 10 2016 jimmy@boombatower.com
- Add invoke-libstdc-removal-before-starting-steam.patch to resolve
  long standing issue:
  https://github.com/ValveSoftware/steam-for-linux/issues/3273
* Mon Jun 13 2016 mailaender@opensuse.org
- update to version 1.0.0.52
- add SteamVR (HTC Vive) support
- add (Debian) changelog
* Fri Apr 29 2016 mailaender@opensuse.org
- don't strip the translation from .desktop file (fixes boo#974334)
* Sat Mar  5 2016 mailaender@opensuse.org
- add Steam controller support
* Sat Nov 21 2015 mailaender@opensuse.org
- update to version 1.0.0.51
* Thu Sep 10 2015 ecsos@opensuse.org
- fix build error for openSUSE 13.1 and 13.2
* Wed Sep  9 2015 dimstar@opensuse.org
- on openSUSE Leap 42.1, we have libgcrypt20-32bit.
* Mon Jun 22 2015 robert.munteanu@gmail.com
- Require alsa-devel to fix launching of unity3D games (
    https://github.com/ValveSoftware/steam-for-linux/issues/3888 )
* Wed May 13 2015 mailaender@opensuse.org
- update to version 1.0.0.50
  * Added libXinerama and libXext to the bootstrap runtime to fix AMD
    graphics driver crashing if these aren't present.
* Mon Dec 29 2014 mailaender@opensuse.org
- remove Fedora exceptions as they got their own RPM
- rework this from fetch script to a real package
- adhere to en.opensuse.org/SourceUrls
- adhere to en.opensuse.org/openSUSE:Packaging_desktop_menu_categories
- clean the package from duplicate icon files
* Sat Oct  4 2014 mailaender@opensuse.org
- update to 1.0.0.49
  * Update packaged icons.
  * Update liblibstdc++ file version to match new runtime.
* Tue Jul  8 2014 speilicke@suse.com
- Require libgcrypt20 on 13.20 or newer, libgcrypt11 was dropped there
* Fri Jun 20 2014 romulasry@gmail.com
- update to 1.0.0.48
* Wed May 28 2014 martadinata666@gmail.com
- update to 1.0.0.47
* Thu Dec 26 2013 mailaender@opensuse.org
- Don't spam the subscriber agreement in the RPM console as Steam
  itself will display a proper EULA in a GUI to accept on first
  start when it downloads the real runtime and client.
- Update instructions of the RPM file description.
- Added missing desktop, icon, mime database update macros.
* Thu Dec  5 2013 mailaender@opensuse.org
- update to 1.0.0.45
- explicit file attributes required in spec to fix build in 12.2
* Sun Dec  1 2013 mihai.petracovici@gmail.com
- Spec file clean-up
  * Package now properly uninstalls
* Sat Nov 23 2013 mailaender@opensuse.org
- update to 1.0.0.44
* Sat Oct 12 2013 mailaender@opensuse.org
- update to 1.0.0.43
* Mon Sep 16 2013 bwiedemann@suse.com
- require dbus-1-glib-32bit libnm-glib4-32bit libnm-util2-32bit
* Mon Sep  9 2013 mailaender@opensuse.org
- update to 1.0.0.41
* Sun Jul  7 2013 mailaender@opensuse.org
- update to 1.0.0.39
* Wed Mar 13 2013 mailaender@opensuse.org
- update to 1.0.0.36
- display EULA before installation
* Tue Mar 12 2013 mailaender@opensuse.org
- fix openal dependency for openSUSE 12.3 (bnc#808951)
* Wed Mar  6 2013 mailaender@opensuse.org
- update to 1.0.0.35
- fix problems with 32bit dependencies on x64 (bnc#806576)
* Sun Feb 24 2013 mailaender@opensuse.org
- update to 1.0.0.33
- require tar instead of ar since we don't unpack a .deb anymore
- use lynx to dump only the text of the EULA without HTML tags
* Sat Feb 23 2013 buschmann23@opensuse.org
- added make and binutils explicit to the Requirements
* Tue Feb 19 2013 buschmann23@opensuse.org
- added conditional to requirements of gcc libs because names
  changed in openSUSE 12.3
* Sun Feb 17 2013 i@marguerite.su
- add Requires: libXdmcp6-32bit.
* Sat Feb 16 2013 mailaender@opensuse.org
- update to 1.0.0.28
* Sun Feb 10 2013 mailaender@opensuse.org
- updated to 1.0.0.25
- use the new tar.gz provided by Valve
* Fri Feb  1 2013 mailaender@opensuse.org
- updated to 1.0.0.22
- created fetch-steam.sh to circumvent the "Limited Installation License"
- removed all non-free binaries and scripts distributed by Valve
* Fri Dec 21 2012 prusnak@opensuse.org
- updated to 1.0.0.18
* Thu Dec 20 2012 prusnak@opensuse.org
- spec cleanup
* Sat Dec  8 2012 jdmulloy@gmail.com
- Added support for x86_64 packages
- Fixed libpng dependency for openSUSE
- Added libopenal1-soft and Mesa-libGL1 dependencices for openSUSE
* Tue Nov 20 2012 mailaender@opensuse.org
- SUSE specific fixes
* Wed Nov  7 2012 spot@fedoraproject.org
- add more Requires (from downloaded bits, not packaged bits)
* Tue Nov  6 2012 spot@fedoraproject.org
- fedora specific libpng conditionalization
* Tue Nov  6 2012 spot@fedoraproject.org
- initial Fedora RPM packaging
